document.addEventListener('DOMContentLoaded', function() {
    // Timeline Animation
    const timelineItems = document.querySelectorAll('.timeline-item');
    
    const observer = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                entry.target.style.opacity = 1;
                entry.target.style.transform = 'translateY(0)';
            }
        });
    });

    timelineItems.forEach(item => {
        item.style.opacity = 0;
        item.style.transform = 'translateY(20px)';
        item.style.transition = 'all 0.5s ease-out';
        observer.observe(item);
    });

    // Population Chart
    const ctx = document.getElementById('populationChart').getContext('2d');
    
    // Simple line chart using canvas API
    function drawChart() {
        const data = [
            {year: 1850, population: 50},
            {year: 1880, population: 300},
            {year: 1920, population: 200},
            {year: 1960, population: 400},
            {year: 2000, population: 800},
            {year: 2020, population: 1000}
        ];

        const canvas = ctx.canvas;
        const width = canvas.width;
        const height = canvas.height;

        ctx.clearRect(0, 0, width, height);
        ctx.beginPath();
        ctx.moveTo(0, height - (data[0].population / 10));

        data.forEach((point, index) => {
            const x = (width / (data.length - 1)) * index;
            const y = height - (point.population / 10);
            ctx.lineTo(x, y);
        });

        ctx.strokeStyle = '#c41e3a';
        ctx.lineWidth = 2;
        ctx.stroke();
    }

    drawChart();
    window.addEventListener('resize', drawChart);

    // Smooth Scroll
    document.querySelectorAll('a[href^="#"]').forEach(anchor => {
        anchor.addEventListener('click', function (e) {
            e.preventDefault();
            document.querySelector(this.getAttribute('href')).scrollIntoView({
                behavior: 'smooth'
            });
        });
    });
});
